#include <iostream>
#include <vector>
#include <set>
#include <numeric>

#define MAXINT std::numeric_limits<int>::max()
#define ENDL '\n'

namespace {
using pointvec_t = std::vector<std::pair<int, int>>;
using pointset_t = std::set<std::pair<int, int>>;

auto recurse(pointvec_t const& points, pointset_t& set_a, int curr_idx) -> int {
    if (curr_idx >= points.size()) {
        if (!set_a.empty()) {
            pointset_t set_b;
            for (auto& point : points) {
                if (set_a.find(point) != set_a.end()) {
                    continue;
                }

                set_b.emplace(point.second, point.first);
            }

            if (!set_b.empty()) {
                auto width_delta = set_a.rbegin()->first - set_a.begin()->first;
                auto height_delta = set_b.rbegin()->first  - set_b.begin()->first;

                // std::cout << width_delta + height_delta << std::endl;

                return width_delta + height_delta;
            }
        }

        return MAXINT;
    }

    auto curr_point = points[curr_idx];

    set_a.emplace(curr_point);
    auto res_insert = recurse(points, set_a, curr_idx + 1);
    set_a.erase(curr_point);

    auto res_skip = recurse(points, set_a, curr_idx + 1);

    return std::min(res_insert, res_skip);
}

auto solve(pointvec_t const& points) {
    pointset_t set_a;
    return recurse(points, set_a, 0);;
}
}  // namespace

int main() {
    std::ios_base::sync_with_stdio(false);
    std::cin.tie(nullptr);
    std::cout.tie(nullptr);

    int n;
    std::cin >> n;

    pointvec_t points;
    points.reserve(n);

    int x, y;
    while (n--) {
        std::cin >> x >> y;
        points.emplace_back(x, y);
    }

    std::cout << solve(points) << ENDL;

    return 0;
}
