#include <iostream>
#include <vector>
#include <set>
#include <numeric>

#define MININT std::numeric_limits<int>::min()
#define MAXINT std::numeric_limits<int>::max()

#define ENDL '\n'

namespace {
using pointvec_t = std::vector<std::pair<int, int>>;
using pointset_t = std::set<std::pair<int, int>>;

auto recurse(pointvec_t const& points, int curr_idx, int min_width, int max_width, int min_height, int max_height) -> int {
    if (curr_idx >= points.size()) {
        if (min_width == MAXINT || max_width == MININT || min_height == MAXINT || max_height == MININT) {
            return MAXINT;
        }

        return (max_width - min_width) + (max_height - min_height);
    }

    auto [curr_width, curr_height] = points[curr_idx];

    auto res_insert_a = recurse(points, curr_idx + 1, std::min(min_width, curr_width), std::max(max_width, curr_width), min_height, max_height);
    auto res_insert_b = recurse(points, curr_idx + 1, min_width, max_width, std::min(min_height, curr_height), std::max(max_height, curr_height));

    return std::min(res_insert_a, res_insert_b);
}

auto solve(pointvec_t const& points) {
    return recurse(points, 0, MAXINT, MININT, MAXINT, MININT);
}
}  // namespace

int main() {
    std::ios_base::sync_with_stdio(false);
    std::cin.tie(nullptr);
    std::cout.tie(nullptr);

    int n;
    std::cin >> n;

    pointvec_t points;
    points.reserve(n);

    int x, y;
    while (n--) {
        std::cin >> x >> y;
        points.emplace_back(x, y);
    }

    std::cout << solve(points) << ENDL;

    return 0;
}
