#include <algorithm>
#include <iostream>
#include <vector>

using namespace std;

const int MAXN = 1e6 + 5;
const long long inf = 1e15 + 5;

struct MinMax
{
    int minVal, maxVal;

    MinMax(){}
    MinMax(int x)
    {
        this->minVal = x;
        this->maxVal = x;
    }
    MinMax(int minVal, int maxVal)
    {
        this->minVal = minVal;
        this->maxVal = maxVal;
    }

    long long getVal()
    {
        return maxVal - minVal;
    }
};

MinMax Merge(MinMax A, MinMax B)
{
    return MinMax(min(A.minVal, B.minVal), max(A.maxVal, B.maxVal));
}

int n;
pair <int, int> p[MAXN];

long long prefSum[MAXN];
MinMax valPref[MAXN], valSuff[MAXN];

void init()
{
    sort(p, p+n);

    prefSum[0] = p[0].first;
    for(int i = 1;i<n;i++) prefSum[i] = prefSum[i-1] + p[i].first;

    valPref[0] = MinMax(p[0].second);
    for(int i = 1;i<n;i++) valPref[i] = Merge(valPref[i-1], MinMax(p[i].second));

    valSuff[n-1] = MinMax(p[n-1].second);
    for(int i = n-2;i>=0;i--) valSuff[i] = Merge(valSuff[i+1], MinMax(p[i].second));
}

long long getSum(int l, int r)
{
    if(l==0) return prefSum[r];
    return prefSum[r] - prefSum[l-1];
}

long long getDiff(int i, int j)
{
    return p[j].first - p[i].first;
}

//започваме само от индекс 0 или n-1
long long arbeit1()
{
    long long ans = inf;
    for(int i = 0;i<n-1;i++)
    {
        ans = min(ans, getSum(0, i) + valSuff[i+1].getVal());
    }
    for(int i = 1;i<n;i++)
    {
        ans = min(ans, getSum(i, n-1) + valPref[i-1].getVal());
    }

    return ans;
}

long long arbeitFurDeutschland()
{
    long long ans = inf;
    for(int i = 1;i<n-1;i++)
    {
        for(int j = i;j<n-1;j++)
        {
            ans = min(ans, getDiff(i, j) + Merge(valPref[i-1], valSuff[j+1]).getVal());
        }
    }

    return ans;
}

int main()
{
    ios::sync_with_stdio(false);
    cin.tie(NULL);

    cin >> n;
    for(int i = 0;i<n;i++) cin >> p[i].first >> p[i].second;
    init();

    long long ans = inf;
    ans = min(ans, arbeit1());

    ans = min(ans, arbeitFurDeutschland());
    cout << ans << '\n';
}
