#include <functional>
#include <algorithm>
#include <iostream>
#include <vector>

using namespace std;

const int MAXN = 1e6 + 5;
const long long inf = 1e15 + 5;

struct SegmentTree
{
    int l, r;
    long long minVal;

    SegmentTree *L, *R;

    SegmentTree()
    {
        this->minVal = inf;
    }
    SegmentTree(int l,int r) : SegmentTree()
    {
        this->l = l;
        this->r = r;

        this->L = nullptr;
        this->R = nullptr;
    }

    void build()
    {
        if(l==r) return;

        L = new SegmentTree(l, (l+r)/2);
        R = new SegmentTree((l+r)/2+1, r);

        L->build();
        R->build();
    }

    void recalc()
    {
        if(l!=r)
        {
            minVal = min(L->minVal, R->minVal);
        }
    }

    void update(int q, long long newVal)
    {
        if(q<l || q>r) return;
        if(l==r && q==l)
        {
            minVal = newVal;
            return;
        }

        L->update(q, newVal);
        R->update(q, newVal);
        recalc();
    }

    long long query(int ql, int qr)
    {
        if(l>=ql && r<=qr) return minVal;
        if(r<ql || l>qr) return inf;

        return min(L->query(ql, qr), R->query(ql, qr));
    }
};

struct MinMax
{
    long long minVal, maxVal;

    MinMax(){}
    MinMax(int x)
    {
        this->minVal = x;
        this->maxVal = x;
    }
    MinMax(int minVal, int maxVal)
    {
        this->minVal = minVal;
        this->maxVal = maxVal;
    }

    long long getVal()
    {
        return maxVal - minVal;
    }
};

MinMax Merge(MinMax A, MinMax B)
{
    return MinMax(min(A.minVal, B.minVal), max(A.maxVal, B.maxVal));
}

bool operator ==(MinMax A, MinMax B)
{
    if(A.minVal!=B.minVal) return false;
    if(A.maxVal!=B.maxVal) return false;

    return true;
}

bool operator !=(MinMax A, MinMax B)
{
    if(A.minVal!=B.minVal) return true;
    if(A.maxVal!=B.maxVal) return true;

    return false;
}

struct EncodedVal
{
    int l, r;
    long long val;

    int ind;
    bool type;

    EncodedVal(){}
    EncodedVal(int l, int r, long long val, int ind, bool type)
    {
        this->l = l;
        this->r = r;
        this->val = val;

        this->ind = ind;
        this->type = type;
    }
};

const function <bool(EncodedVal, EncodedVal)> EncodedValComparer = [](EncodedVal A, EncodedVal B)
{
    if(A.l!=B.l) return A.l<B.l;
    return A.type<B.type;
};

int n;
pair <int, int> p[MAXN];

long long prefSum[MAXN];
MinMax valPref[MAXN], valSuff[MAXN];

void init()
{
    sort(p, p+n);

    prefSum[0] = p[0].first;
    for(int i = 1;i<n;i++) prefSum[i] = prefSum[i-1] + p[i].first;

    valPref[0] = MinMax(p[0].second);
    for(int i = 1;i<n;i++) valPref[i] = Merge(valPref[i-1], MinMax(p[i].second));

    valSuff[n-1] = MinMax(p[n-1].second);
    for(int i = n-2;i>=0;i--) valSuff[i] = Merge(valSuff[i+1], MinMax(p[i].second));
}

long long getSum(int l, int r)
{
    if(l==0) return prefSum[r];
    return prefSum[r] - prefSum[l-1];
}

long long getDiff(int i, int j)
{
    return p[j].first - p[i].first;
}

//започваме само от индекс 0 или n-1
long long arbeit1()
{
    long long ans = inf;
    for(int i = 0;i<n-1;i++)
    {
        ans = min(ans, getDiff(0, i) + valSuff[i+1].getVal());
    }
    for(int i = 1;i<n;i++)
    {
        ans = min(ans, getDiff(i, n-1) + valPref[i-1].getVal());
    }

    return ans;
}

//реално мин и макс са отляво
long long arbeit2()
{
    long long ans = inf;
    for(int i = 1;i<n-1;i++)
    {
        int l = i, r = n-2, mid;

        while(l+1<r)
        {
            mid = (l+r)/2;

            if(Merge(valPref[i-1], valSuff[mid+1])==valPref[i-1]) r = mid;
            else l = mid + 1;
        }

        int ind = -1;
        if(Merge(valPref[i-1], valSuff[l+1])==valPref[i-1]) ind = l;
        else if(Merge(valPref[i-1], valSuff[r+1])==valPref[i-1]) ind = r;

        if(ind!=-1)
        {
            //cout << i << " -> " << ind << " ||| " << p[ind].first - p[i].first << " + " << valPref[i-1].getVal() << '\n';
            ans = min(ans, p[ind].first - p[i].first + valPref[i-1].getVal());
        }
    }

    return ans;
}

//реално мин и макс са отдясно
long long arbeit3()
{
    long long ans = inf;
    for(int i = n-2;i>=1;i--)
    {
        int l = 1, r = i, mid;
        while(l+1<r)
        {
            mid = (l+r)/2;

            if(Merge(valPref[mid-1], valSuff[i+1])==valSuff[i+1]) l = mid;
            else r = mid - 1;
        }

        int ind = -1;
        if(Merge(valPref[r-1], valSuff[i+1])==valSuff[i+1]) ind = r;
        else if(Merge(valPref[l-1], valSuff[i+1])==valSuff[i+1]) ind = l;

        if(ind!=-1)
        {
            //cout << i << " -> " << ind << " ||| " << p[ind].first - p[i].first << " + " << valPref[i-1].getVal() << '\n';
            ans = min(ans, p[i].first - p[ind].first + valSuff[i+1].getVal());
        }
    }

    return ans;
}

//мин ляво макс дясно
long long arbeit4()
{
    long long ans = inf;
    int indMin = n-2, indMax = n-2;

    for(int i = 1;i<n-1;i++)
    {
        while(indMin<i) indMin++;
        while(indMax<i) indMax++;

        while(indMin>i && min(valPref[i-1].minVal, valSuff[indMin-1+1].minVal)==valPref[i-1].minVal) indMin--;
        while(indMax>i && max(valPref[i-1].maxVal, valSuff[indMax+1].maxVal)!=valSuff[indMax+1].maxVal) indMax--;

        if(indMin<=indMax && indMin>=i && indMax>=i
           && valPref[i-1].minVal<=valSuff[indMin+1].minVal
           && valPref[i-1].maxVal<=valSuff[indMax+1].maxVal)
        {
            for(int j = indMin;j<=indMax;j++)
            {
                ans = min(ans, p[j].first - p[i].first + valSuff[j+1].maxVal - valPref[i-1].minVal);
            }

        }
    }

    return ans;
}

//макс ляво мин дясно
long long arbeit5()
{
    long long ans = inf;
    int indMin = n-2, indMax = n-2;

    for(int i = 1;i<n-1;i++)
    {
        while(indMin<i) indMin++;
        while(indMax<i) indMax++;

        while(indMin>i && min(valPref[i-1].minVal, valSuff[indMin+1].minVal)!=valSuff[indMin+1].minVal) indMin--;
        while(indMax>i && max(valPref[i-1].maxVal, valSuff[indMax-1+1].maxVal)==valPref[i-1].maxVal) indMax--;

        if(indMax<=indMin && indMin>=i && indMax>=i
           && valPref[i-1].minVal>=valSuff[indMin+1].minVal
           && valPref[i-1].maxVal>=valSuff[indMax+1].maxVal)
        {
            for(int j = indMax;j<=indMin;j++)
            {
                ans = min(ans, p[j].first - p[i].first + valPref[i-1].maxVal - valSuff[j+1].minVal);
            }
        }
    }

    return ans;
}

long long arbeitFurDeutschland()
{
    return inf;

    long long ans = inf;
    for(int i = 1;i<n-1;i++)
    {
        for(int j = i;j<n-1;j++)
        {
            MinMax res = Merge(valPref[i-1], valSuff[j+1]);
            //if(res==valPref[i-1]) continue;
            //if(res==valSuff[j+1]) continue;
            //if(res.minVal==valPref[i-1].minVal && res.maxVal==valSuff[j+1].maxVal) continue;

            if(res.maxVal==valPref[i-1].maxVal && res.minVal==valSuff[j+1].minVal)
            {
                //ans = min(ans, getDiff(i, j) + res.getVal());

            }


            //if(getDiff(i, j) + Merge(valPref[i-1], valSuff[j+1]).getVal()==36) cout << i << " " << j << '\n';
        }
    }

    return ans;
}

int main()
{
    ios::sync_with_stdio(false);
    cin.tie(NULL);

    cin >> n;
    for(int i = 0;i<n;i++) cin >> p[i].first >> p[i].second;
    init();

    //cout << " --- " << '\n';
    //for(int i = 0;i<n;i++) cout << i << " -> " << p[i].first << " " << p[i].second << '\n';
    //cout << " --- " << '\n';

    long long ans = inf;
    ans = min(ans, arbeit1());
    ans = min(ans, arbeit2());
    ans = min(ans, arbeit3());
    ans = min(ans, arbeit4());
    ans = min(ans, arbeit5());

    ans = min(ans, arbeitFurDeutschland());
    cout << ans << '\n';
}
